AuthError

Enum AuthError 

pub enum AuthError {
    MissingDateTime(String),
    InvalidAuthorizationHeader(String),
    InvalidCredential(String),
    InvalidHexSignature(String),
    ContextCreationError(String),
    AuthenticationFailed(String),
    UserNotFound(String),
    InvalidSignature(String),
    InvalidUserStatus(String),
    Other(String),
}
Authentication error types.

This enum represents various authentication errors that can occur during the authentication process, including context building, credential validation, and signature verification.

Variants



MissingDateTime(String)

Missing DateTime header in gRPC metadata



InvalidAuthorizationHeader(String)

Invalid Authorization header format



InvalidCredential(String)

Invalid credential format or content



InvalidHexSignature(String)

Invalid hex-encoded signature



ContextCreationError(String)

Generic authentication context creation error



AuthenticationFailed(String)

User authentication failed



UserNotFound(String)

User not found



InvalidSignature(String)

Invalid signature



InvalidUserStatus(String)

User status is not valid (disabled, deleted, etc.)



Other(String)

Generic error with custom message